@@ -2,13 +2,14 @@ from difflib import SequenceMatcher
 from functools import reduce
 
 
-def get_best_match(value, list_values):
+def get_best_match(value, list_values, sort_words=False):
     """
     Returns the best match for a string  between a list of strings based on similarity
 
     Parameters:
         value (str): Main string to find similar
         list_values (list(str)): List of strings to look for similarity
+        sort_words (boolean): If true, words on both string will be sorted
 
     Returns:
         best_match (str): String with higher similarity to value
@@ -18,7 +19,12 @@ def get_best_match(value, list_values):
     best_match = ''
 
     for v in list_values:
-        temp_score = SequenceMatcher(None, str(value).lower(), str(v).lower()).ratio()
+        if sort_words:
+            temp_score = SequenceMatcher(None, " ".join(sorted(str(value).lower().split()))
+                                             , " ".join(sorted(str(v).lower().split()))
+                                             ).ratio()
+        else:
+            temp_score = SequenceMatcher(None, str(value).lower(), str(v).lower()).ratio()
 
         if temp_score > score:
             best_match = v
